#!/usr/bin/env python

from __future__ import annotations

import argparse
import json
import sys

import boto3 as boto3
from botocore.config import Config

sqs_client = boto3.client("sqs", config=Config(retries={"mode": "standard"}))


def sqs_get_queue_url(queue_name: str) -> str:
    res = sqs_client.get_queue_url(QueueName=queue_name)
    return res["QueueUrl"]


def sqs_receive(queue_url: str, delete_flag: bool, wait: int):
    print(f"Receiving from {queue_url}")
    while True:
        res = sqs_client.receive_message(
            QueueUrl=queue_url,
            WaitTimeSeconds=wait,
            AttributeNames=["All"],
        )
        if "Messages" not in res:
            if wait > 0:
                print("No messages...", file=sys.stderr)
                continue
            else:
                break

        for message in res["Messages"]:
            print(json.dumps(message, ensure_ascii=False, indent=2))
            if delete_flag:
                receipt_handle = message["ReceiptHandle"]
                sqs_client.delete_message(
                    QueueUrl=queue_url,
                    ReceiptHandle=receipt_handle,
                )
                print("-> deleted", file=sys.stderr)


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--queue-url")
    parser.add_argument("--queue-name")
    parser.add_argument("-d", "--delete", action="store_true")
    parser.add_argument("--wait", default=0)
    args = parser.parse_args()

    queue_url = args.queue_url
    if not args.queue_url:
        if not args.queue_name:
            print(f"ERROR: queue url or queue name required.")
            exit(1)
        queue_url = sqs_get_queue_url(args.queue_name)
    sqs_receive(queue_url, args.delete, int(args.wait))


if __name__ == "__main__":
    main()
